### Name: returnExpression
### Title: Return the expression of the estimates of parameters
### Aliases: returnExpression
### Keywords: methods multivariate

### ** Examples

library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

# Enter the saturated model:    
enterModel("*", object = CoCoObject);

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE);

# Show the model list:
showModel("all", object = CoCoObject);

makeCurrent("last", object = CoCoObject);

returnExpression(object = CoCoObject);

str(returnExpression(type = "expression", object = CoCoObject));

str(returnExpression(omit.prime.components = TRUE, object = CoCoObject));
str(returnExpression(omit.separators = TRUE, object = CoCoObject));
str(returnExpression(omit.generators = TRUE, object = CoCoObject));

str(returnExpression(type = "separators", object = CoCoObject));
str(returnExpression(type = "prime.components", object = CoCoObject));

str(returnExpression(state.space = TRUE, object = CoCoObject)); # ?

endCoCo(CoCoObject);

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

enterModel("[[a][b]] / [[ay][ax][bx]] / [[xy]]", object = CoCoObject);

showModel("all", object = CoCoObject);

makeCurrent("last", object = CoCoObject);

returnExpression(object = CoCoObject);

str(returnExpression(type = "expression", object = CoCoObject));

str(returnExpression(omit.prime.components = TRUE, object = CoCoObject));
str(returnExpression(omit.separators = TRUE, object = CoCoObject));
str(returnExpression(omit.generators = TRUE, object = CoCoObject));

str(returnExpression(type = "separators", object = CoCoObject));
str(returnExpression(type = "prime.components", object = CoCoObject));

str(returnExpression(state.space = TRUE, object = CoCoObject)); # ?

str(returnExpression(return.flags = TRUE, object = CoCoObject));

str(returnExpression(split.sets = TRUE, object = CoCoObject)); # ?
str(returnExpression(eliminate.empty = FALSE, object = CoCoObject)); # ?

str(returnExpression(type = "junction.tree.components",
                     split.models = FALSE, object = CoCoObject));

str(returnExpression(type = "junction.tree.components",
                     split.generators = FALSE, object = CoCoObject));

endCoCo(CoCoObject);

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

data(Fuchs82);

CoCoObject <- makeCoCo();
enterTable(Fuchs82, object = CoCoObject);

enterModel("mdp,da,am,dg,gs,sa", object = CoCoObject);

# State-space, with generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = FALSE, state.space = TRUE, object = CoCoObject);

# State-space, without generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = TRUE, object = CoCoObject);

showFormula(object = CoCoObject);

# State-space, with generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = FALSE, state.space = TRUE, object = CoCoObject);

# State-space, without generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = TRUE, object = CoCoObject);

# Expression:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = FALSE, state.space = FALSE, object = CoCoObject);

# Expression, without generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = FALSE, object = CoCoObject);

# Prime components:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = TRUE,
                 omit.generators = TRUE, state.space = FALSE, object = CoCoObject);
returnExpression(model = FALSE, type = "prime.components", object = CoCoObject);

# Separators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = TRUE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = FALSE, object = CoCoObject);
returnExpression(model = FALSE, type = "separators", object = CoCoObject);

endCoCo(object = CoCoObject);



